pub struct BuildGeneration(pub u64);Expand description
Monotonic label for one build of one content snapshot. Stale build completions are recognized by generation, never by timing.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for BuildGeneration
impl Clone for BuildGeneration
Sourcefn clone(&self) -> BuildGeneration
fn clone(&self) -> BuildGeneration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for BuildGeneration
Sourceimpl Debug for BuildGeneration
impl Debug for BuildGeneration
impl Eq for BuildGeneration
Sourceimpl Ord for BuildGeneration
impl Ord for BuildGeneration
Sourcefn cmp(&self, other: &BuildGeneration) -> Ordering
fn cmp(&self, other: &BuildGeneration) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BuildGeneration
impl PartialEq for BuildGeneration
Sourceimpl PartialOrd for BuildGeneration
impl PartialOrd for BuildGeneration
impl StructuralPartialEq for BuildGeneration