frame new — deterministic, atomic application scaffolding.
Structs
- NewOptions
- Inputs to one deterministic scaffold generation.
Enums
- GitError
- A failure running one of the git commands that DID run (never a missing-git
or already-inside-a-repo condition — those are reported as
GitInit). - GitInit
- What
frame newdid about version control for the new tree. - NewError
- Typed refusal or generation failure from
frame new.
Functions
- generate
- Atomically generates one application tree.
- init_
repo - Initialises a git repository in
targetand makes one initial commit, unlesstargetis already inside a git work tree (skipped and reported) or git is not installed (skipped and reported). - validate_
name - Validates an application name against both language rules.